@@ -1,7 +1,7 @@
 package App::CSVUtils;
 
-our $DATE = '2019-06-06'; # DATE
-our $VERSION = '0.023'; # VERSION
+our $DATE = '2019-11-14'; # DATE
+our $VERSION = '0.024'; # VERSION
 
 use 5.010001;
 use strict;
@@ -335,6 +335,7 @@ $SPEC{csvutil} = {
                 'sum',
                 'avg',
                 'select-row',
+                'split',
                 'grep',
                 'map',
                 'each-row',
@@ -389,6 +390,9 @@ sub csvutil {
     my $selected_row;
     my $row_spec_sub;
 
+    # for action=split
+    my ($split_fh, $split_filename, $split_lines);
+
     my $row0;
     my $code_getline = sub {
         if ($i == 0 && !$has_header) {
@@ -618,6 +622,27 @@ sub csvutil {
             if ($i == 1 || $row_spec_sub->($i)) {
                 $res .= _get_csv_row($csv, $row, $i, $has_header);
             }
+        } elsif ($action eq 'split') {
+            next if $i == 1;
+            unless (defined $split_fh) {
+                $split_filename = "xaa";
+                $split_lines = 0;
+                open $split_fh, ">", $split_filename
+                    or die "Can't open '$split_filename': $!\n";
+            }
+            if ($split_lines >= $args{lines}) {
+                $split_filename++;
+                $split_lines = 0;
+                open $split_fh, ">", $split_filename
+                    or die "Can't open '$split_filename': $!\n";
+            }
+            if ($split_lines == 0 && $has_header) {
+                $csv->print($split_fh, $fields);
+                print $split_fh "\n";
+            }
+            $csv->print($split_fh, $row);
+            print $split_fh "\n";
+            $split_lines++;
         } elsif ($action eq 'grep') {
             unless ($code) {
                 $code = _compile($args{eval});
@@ -1139,6 +1164,9 @@ $SPEC{csv_select_row} = {
             pos => 1,
         },
     },
+    links => [
+        {url=>"prog:csv-split"},
+    ],
 };
 sub csv_select_row {
     my %args = @_;
@@ -1146,6 +1174,46 @@ sub csv_select_row {
     csvutil(%args, action=>'select-row');
 }
 
+$SPEC{csv_split} = {
+    v => 1.1,
+    summary => 'Split CSV file into several files',
+    description => <<'_',
+
+Will output split files xaa, xab, and so on. Each split file will contain a
+maximum of `lines` rows (options to limit split files' size based on number of
+characters and bytes will be added). Each split file will also contain CSV
+header.
+
+Warning: by default, existing split files xaa, xab, and so on will be
+overwritten.
+
+Interface is loosely based on the `split` Unix utility.
+
+_
+    args => {
+        %args_common,
+        %arg_filename_0,
+        lines => {
+            schema => ['uint*', min=>1],
+            default => 1000,
+            cmdline_aliases => {l=>{}},
+        },
+        # XXX --bytes (-b)
+        # XXX --line-bytes (-C)
+        # XXX -d (numeric suffix)
+        # --suffix-length (-a)
+        # --number, -n (chunks)
+    },
+    links => [
+        {url=>"prog:csv-select-row"},
+    ],
+};
+sub csv_split {
+    my %args = @_;
+
+    csvutil(%args, action=>'split');
+}
+
 $SPEC{csv_grep} = {
     v => 1.1,
     summary => 'Only output row(s) where Perl expression returns true',
@@ -1975,7 +2043,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 0.023 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-06-06.
+This document describes version 0.024 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2019-11-14.
 
 =head1 DESCRIPTION
 
@@ -2023,6 +2091,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-sort-rows>
 
+=item * L<csv-split>
+
 =item * L<csv-sum>
 
 =item * L<csv2ltsv>
@@ -2114,6 +2184,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_avg
 
 Usage:
@@ -2164,6 +2235,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_concat
 
 Usage:
@@ -2240,6 +2312,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_convert_to_hash
 
 Usage:
@@ -2290,6 +2363,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_delete_field
 
 Usage:
@@ -2340,6 +2414,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_dump
 
 Usage:
@@ -2390,6 +2465,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_each_row
 
 Usage:
@@ -2460,6 +2536,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_grep
 
 Usage:
@@ -2542,6 +2619,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_info
 
 Usage:
@@ -2588,6 +2666,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_list_field_names
 
 Usage:
@@ -2634,6 +2713,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_lookup_fields
 
 Usage:
@@ -2720,6 +2800,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_map
 
 Usage:
@@ -2802,6 +2883,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_munge_field
 
 Usage:
@@ -2862,6 +2944,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_replace_newline
 
 Usage:
@@ -2916,6 +2999,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_select_fields
 
 Usage:
@@ -2970,6 +3054,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_select_row
 
 Usage:
@@ -3020,6 +3105,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_setop
 
 Usage:
@@ -3147,6 +3233,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_sort_fields
 
 Usage:
@@ -3216,6 +3303,7 @@ that contains extra information.
 Return value:  (any)
 
 
+
 =head2 csv_sort_rows
 
 Usage:
@@ -3343,6 +3431,66 @@ that contains extra information.
 Return value:  (any)
 
 
+
+=head2 csv_split
+
+Usage:
+
+ csv_split(%args) -> [status, msg, payload, meta]
+
+Split CSV file into several files.
+
+Will output split files xaa, xab, and so on. Each split file will contain a
+maximum of C<lines> rows (options to limit split files' size based on number of
+characters and bytes will be added). Each split file will also contain CSV
+header.
+
+Warning: by default, existing split files xaa, xab, and so on will be
+overwritten.
+
+Interface is loosely based on the C<split> Unix utility.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<filename>* => I<filename>
+
+Input CSV file.
+
+=item * B<header> => I<bool> (default: 1)
+
+Whether CSV has a header row.
+
+By default (C<--header>), the first row of the CSV will be assumed to contain
+field names (and the second row contains the first data row). When you declare
+that CSV does not have header row (C<--no-header>), the first row of the CSV is
+assumed to contain the first data row. Fields will be named C<field1>, C<field2>,
+and so on.
+
+=item * B<lines> => I<uint> (default: 1000)
+
+=item * B<tsv> => I<bool>
+
+Inform that input file is in TSV (tab-separated) format instead of CSV.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 csv_sum
 
 Usage:
@@ -3435,10 +3583,14 @@ L<App::LTSVUtils>
 L<App::SerializeUtils>
 
 
+L<csv-select-row>.
+
 L<csvgrep>.
 
 L<setop>.
 
+L<csv-split>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
